{ nix-config, config, lib, pkgs, inputs, ... }:
let
  # scpath = "/home/emenel/.config/sops-nix/secrets";
in
{

  imports = with nix-config.homeModules; [
    git-conf
    yazi
    shell-conf # shell, shell utils, cli tools, libs, tui's
    email
    desktop
    music
    langs
    mpd
    beets
    emacs
  ];

  home = {
    packages = lib.mkMerge [
      (with inputs.affinity-nix.packages.x86_64-linux; [
        photo
        publisher
        designer
      ])

      (with pkgs; [
        dconf
        cifs-utils
        (btop.override { cudaSupport = true; rocmSupport = true; })
        ispell
        wordnet
        artha
        (aspellWithDicts (dicts: with dicts; [ en en-computers en-science es fr ]))
        texlive.combined.scheme-full
        openrgb-with-all-plugins
        bazecor
        faircamp
        sqlite
        qmk
        qmk-udev-rules
        qmk_hid
      ])
    ];

    username = "emenel";
    homeDirectory = "/home/emenel";

    sessionPath = [ "/home/emenel/.config/emacs/bin"
                    "/home/emenel/.npm-packages/bin"
                    "/home/emenel/Applications"
                    "/home/emenel/.local/bin"
                    "/home/emenel/.local/share"
                    "/home/emenel/.nix-profile/lib"
                    "/etc/profiles/per-user/emenel/bin/"
                    "/home/emenel/.local/state/nix/profiles/home-manager/home-path/bin/" ];

    sessionVariables = {
      WINEFSYNC = 1;
      PKG_CONFIG_PATH = "/home/emenel/.nix-profile/lib/pkgconfig:/home/emenel/.nix-profile/lib64/pkgconfig:/home/emenal/.nix-profile/share/pkgconfig";
      GI_TYPELIB_PATH = "/run/current-system/sw/lib/girepository-1.0";
      NIXOS_OZONE_WL = "1";
      GSK_RENDERER = "ngl";
      MOZ_ENABLE_WAYLAND = 1;
      LSP_USE_PLISTS = "true";
      GDK_BACKEND= "wayland";
      NH_FLAKE = "\${HOME}/source/nixos-config";
      GTRASH_PUT_RM_MODE = "true";
    };

    stateVersion = "25.05";
  };

  programs = {
    home-manager.enable = true;

    pandoc.enable = true;
    password-store.enable = true;

    rclone = {
      enable = true;
    };
    
    borgmatic = {
      enable = true;
      backups = {
        eddie = {
          location = {
            excludeHomeManagerSymlinks = true;
            patterns = [
              "R /home/emenel"
              "- .cache"
              "- .nix*"
              "- .steam*"
              "- sync"
              "- mounts"
              "- .BitwigStudio"
              "- .local/share/bitwig"
              "- .local/share/flatpak"
            ];
            repositories = [
              {
                "path" = "ssh://oyi3ydnz@oyi3ydnz.repo.borgbase.com/./repo";
                "label" = "eddie on borgbase";
              }
            ];
          };
          retention = {
            keepDaily = 7;
            keepHourly = 3;
            keepMonthly = 6;
          };
        };
      };
    };
  };

  services = {
    borgmatic = {
      enable = true;
    };
    gpg-agent = {
      enable = true;
    };
  };

  xdg.systemDirs.data = [
    "/home/emenel/.local/share/applications/wine/Programs"
    "/home/emenel/.local/share/applications"
    "/var/lib/flatpak/exports/share"
  ];

  systemd.user = {
    enable = true;
    startServices = "sd-switch"; # auto reload services when home is rebuilt
    sessionVariables = {
      GSK_RENDERER = "ngl";
      QT_QPA_PLATFORM = "xcb";
      MOZ_ENABLE_WAYLAND = 1;
      # XCURSOR_SIZE = 32;
      # XCURSOR_THEME = "Bibata-Modern-Classic";
      DISPLAY = ":0";
      WAYLAND_DISPLAY="wayland-1";
      ELECTRON_OZONE_PLATFORM_HINT = "auto";
    };
  };

  systemd.user.tmpfiles.rules = [
    "L /home/emenel/mounts - - - - /mnt"
    "L /home/emenel/Documents - - - - /home/emenel/documents"
  ];

  xdg.configFile."xdg-desktop-portal-termfilechooser" = {
    source = ../../modules/home/file-chooser;
    recursive = true;
  };

  home = {
    file = {
      ".signature".source = ./dotfiles/dot_signature;
      ".local/bin" = {
        source = ./dotfiles/dot_local/bin;
        recursive = true;
      };
      ".ssh/config".source = ./dotfiles/dot_ssh/config;
    };
  };
}
